package java.awt;

import java.beans.Transient;
import java.io.Serializable;
import java.awt.geom.Rectangle2D;

public class Rectangle extends Rectangle2D implements Shape, Serializable
{
    public int x;
    public int y;
    public int width;
    public int height;
    private static final long serialVersionUID = -4345857070255674764L;
    
    private static native void initIDs();
    
    public Rectangle() {
        this(0, 0, 0, 0);
    }
    
    public Rectangle(Rectangle rectangle) {
        this(rectangle.x, rectangle.y, rectangle.width, rectangle.height);
    }
    
    public Rectangle(int x, int y, int width, int height) {
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
    }
    
    public Rectangle(int n, int n2) {
        this(0, 0, n, n2);
    }
    
    public Rectangle(Point point, Dimension dimension) {
        this(point.x, point.y, dimension.width, dimension.height);
    }
    
    public Rectangle(Point point) {
        this(point.x, point.y, 0, 0);
    }
    
    public Rectangle(Dimension dimension) {
        this(0, 0, dimension.width, dimension.height);
    }
    
    @Override
    public double getX() {
        return (double)this.x;
    }
    
    @Override
    public double getY() {
        return (double)this.y;
    }
    
    @Override
    public double getWidth() {
        return (double)this.width;
    }
    
    @Override
    public double getHeight() {
        return (double)this.height;
    }
    
    @Transient
    @Override
    public Rectangle getBounds() {
        return new Rectangle(this.x, this.y, this.width, this.height);
    }
    
    @Override
    public Rectangle2D getBounds2D() {
        return new Rectangle(this.x, this.y, this.width, this.height);
    }
    
    public void setBounds(Rectangle rectangle) {
        this.setBounds(rectangle.x, rectangle.y, rectangle.width, rectangle.height);
    }
    
    public void setBounds(int n, int n2, int n3, int n4) {
        this.reshape(n, n2, n3, n4);
    }
    
    @Override
    public void setRect(double n, double n2, double n3, double n4) {
        int clip;
        int clip2;
        if (n > 4.294967294E9) {
            clip = Integer.MAX_VALUE;
            clip2 = -1;
        }
        else {
            clip = clip(n, false);
            if (n3 >= 0.0) {
                n3 += n - (double)clip;
            }
            clip2 = clip(n3, n3 >= 0.0);
        }
        int clip3;
        int clip4;
        if (n2 > 4.294967294E9) {
            clip3 = Integer.MAX_VALUE;
            clip4 = -1;
        }
        else {
            clip3 = clip(n2, false);
            if (n4 >= 0.0) {
                n4 += n2 - (double)clip3;
            }
            clip4 = clip(n4, n4 >= 0.0);
        }
        this.reshape(clip, clip3, clip2, clip4);
    }
    
    private static int clip(double n, boolean b) {
        if (n <= -2.147483648E9) {
            return Integer.MIN_VALUE;
        }
        if (n >= 2.147483647E9) {
            return Integer.MAX_VALUE;
        }
        return (int)(b ? Math.ceil(n) : Math.floor(n));
    }
    
    @Deprecated
    public void reshape(int x, int y, int width, int height) {
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
    }
    
    public Point getLocation() {
        return new Point(this.x, this.y);
    }
    
    public void setLocation(Point point) {
        this.setLocation(point.x, point.y);
    }
    
    public void setLocation(int n, int n2) {
        this.move(n, n2);
    }
    
    @Deprecated
    public void move(int x, int y) {
        this.x = x;
        this.y = y;
    }
    
    public void translate(int n, int n2) {
        int x = this.x;
        int x2 = x + n;
        if (n < 0) {
            if (x2 > x) {
                if (this.width >= 0) {
                    this.width += x2 - Integer.MIN_VALUE;
                }
                x2 = Integer.MIN_VALUE;
            }
        }
        else if (x2 < x) {
            if (this.width >= 0) {
                this.width += x2 - Integer.MAX_VALUE;
                if (this.width < 0) {
                    this.width = Integer.MAX_VALUE;
                }
            }
            x2 = Integer.MAX_VALUE;
        }
        this.x = x2;
        int y = this.y;
        int y2 = y + n2;
        if (n2 < 0) {
            if (y2 > y) {
                if (this.height >= 0) {
                    this.height += y2 - Integer.MIN_VALUE;
                }
                y2 = Integer.MIN_VALUE;
            }
        }
        else if (y2 < y) {
            if (this.height >= 0) {
                this.height += y2 - Integer.MAX_VALUE;
                if (this.height < 0) {
                    this.height = Integer.MAX_VALUE;
                }
            }
            y2 = Integer.MAX_VALUE;
        }
        this.y = y2;
    }
    
    public Dimension getSize() {
        return new Dimension(this.width, this.height);
    }
    
    public void setSize(Dimension dimension) {
        this.setSize(dimension.width, dimension.height);
    }
    
    public void setSize(int n, int n2) {
        this.resize(n, n2);
    }
    
    @Deprecated
    public void resize(int width, int height) {
        this.width = width;
        this.height = height;
    }
    
    public boolean contains(Point point) {
        return this.contains(point.x, point.y);
    }
    
    public boolean contains(int n, int n2) {
        return this.inside(n, n2);
    }
    
    public boolean contains(Rectangle rectangle) {
        return this.contains(rectangle.x, rectangle.y, rectangle.width, rectangle.height);
    }
    
    public boolean contains(int n, int n2, int n3, int n4) {
        int width = this.width;
        int height = this.height;
        if ((width | height | n3 | n4) < 0) {
            return false;
        }
        int x = this.x;
        int y = this.y;
        if (n < x || n2 < y) {
            return false;
        }
        int n5 = width + x;
        n3 += n;
        if (n3 <= n) {
            if (n5 >= x || n3 > n5) {
                return false;
            }
        }
        else if (n5 >= x && n3 > n5) {
            return false;
        }
        int n6 = height + y;
        n4 += n2;
        if (n4 <= n2) {
            if (n6 >= y || n4 > n6) {
                return false;
            }
        }
        else if (n6 >= y && n4 > n6) {
            return false;
        }
        return true;
    }
    
    @Deprecated
    public boolean inside(int n, int n2) {
        int width = this.width;
        int height = this.height;
        if ((width | height) < 0) {
            return false;
        }
        int x = this.x;
        int y = this.y;
        if (n < x || n2 < y) {
            return false;
        }
        int n3 = width + x;
        int n4 = height + y;
        return (n3 < x || n3 > n) && (n4 < y || n4 > n2);
    }
    
    public boolean intersects(Rectangle rectangle) {
        int width = this.width;
        int height = this.height;
        int width2 = rectangle.width;
        int height2 = rectangle.height;
        if (width2 <= 0 || height2 <= 0 || width <= 0 || height <= 0) {
            return false;
        }
        int x = this.x;
        int y = this.y;
        int x2 = rectangle.x;
        int y2 = rectangle.y;
        int n = width2 + x2;
        int n2 = height2 + y2;
        int n3 = width + x;
        int n4 = height + y;
        return (n < x2 || n > x) && (n2 < y2 || n2 > y) && (n3 < x || n3 > x2) && (n4 < y || n4 > y2);
    }
    
    public Rectangle intersection(Rectangle rectangle) {
        int x = this.x;
        int y = this.y;
        int x2 = rectangle.x;
        int y2 = rectangle.y;
        long n = (long)x + (long)this.width;
        long n2 = (long)y + (long)this.height;
        long n3 = (long)x2 + (long)rectangle.width;
        long n4 = (long)y2 + (long)rectangle.height;
        if (x < x2) {
            x = x2;
        }
        if (y < y2) {
            y = y2;
        }
        if (n > n3) {
            n = n3;
        }
        if (n2 > n4) {
            n2 = n4;
        }
        long n5 = n - (long)x;
        long n6 = n2 - (long)y;
        if (n5 < -2147483648L) {
            n5 = -2147483648L;
        }
        if (n6 < -2147483648L) {
            n6 = -2147483648L;
        }
        return new Rectangle(x, y, (int)n5, (int)n6);
    }
    
    public Rectangle union(Rectangle rectangle) {
        long n = (long)this.width;
        long n2 = (long)this.height;
        if ((n | n2) < 0L) {
            return new Rectangle(rectangle);
        }
        long n3 = (long)rectangle.width;
        long n4 = (long)rectangle.height;
        if ((n3 | n4) < 0L) {
            return new Rectangle(this);
        }
        int x = this.x;
        int y = this.y;
        long n5 = n + (long)x;
        long n6 = n2 + (long)y;
        int x2 = rectangle.x;
        int y2 = rectangle.y;
        long n7 = n3 + (long)x2;
        long n8 = n4 + (long)y2;
        if (x > x2) {
            x = x2;
        }
        if (y > y2) {
            y = y2;
        }
        if (n5 < n7) {
            n5 = n7;
        }
        if (n6 < n8) {
            n6 = n8;
        }
        long n9 = n5 - (long)x;
        long n10 = n6 - (long)y;
        if (n9 > 2147483647L) {
            n9 = 2147483647L;
        }
        if (n10 > 2147483647L) {
            n10 = 2147483647L;
        }
        return new Rectangle(x, y, (int)n9, (int)n10);
    }
    
    public void add(int x, int y) {
        if ((this.width | this.height) < 0) {
            this.x = x;
            this.y = y;
            int n7 = 0;
            this.height = n7;
            this.width = n7;
            return;
        }
        int x2 = this.x;
        int y2 = this.y;
        long n = (long)this.width;
        long n2 = (long)this.height;
        long n3 = n + (long)x2;
        long n4 = n2 + (long)y2;
        if (x2 > x) {
            x2 = x;
        }
        if (y2 > y) {
            y2 = y;
        }
        if (n3 < (long)x) {
            n3 = (long)x;
        }
        if (n4 < (long)y) {
            n4 = (long)y;
        }
        long n5 = n3 - (long)x2;
        long n6 = n4 - (long)y2;
        if (n5 > 2147483647L) {
            n5 = 2147483647L;
        }
        if (n6 > 2147483647L) {
            n6 = 2147483647L;
        }
        this.reshape(x2, y2, (int)n5, (int)n6);
        return;
    }
    
    public void add(Point point) {
        this.add(point.x, point.y);
    }
    
    public void add(Rectangle rectangle) {
        long n = (long)this.width;
        long n2 = (long)this.height;
        if ((n | n2) < 0L) {
            this.reshape(rectangle.x, rectangle.y, rectangle.width, rectangle.height);
        }
        long n3 = (long)rectangle.width;
        long n4 = (long)rectangle.height;
        if ((n3 | n4) < 0L) {
            return;
        }
        int x = this.x;
        int y = this.y;
        long n5 = n + (long)x;
        long n6 = n2 + (long)y;
        int x2 = rectangle.x;
        int y2 = rectangle.y;
        long n7 = n3 + (long)x2;
        long n8 = n4 + (long)y2;
        if (x > x2) {
            x = x2;
        }
        if (y > y2) {
            y = y2;
        }
        if (n5 < n7) {
            n5 = n7;
        }
        if (n6 < n8) {
            n6 = n8;
        }
        long n9 = n5 - (long)x;
        long n10 = n6 - (long)y;
        if (n9 > 2147483647L) {
            n9 = 2147483647L;
        }
        if (n10 > 2147483647L) {
            n10 = 2147483647L;
        }
        this.reshape(x, y, (int)n9, (int)n10);
        return;
    }
    
    public void grow(int n, int n2) {
        long n3 = (long)this.x;
        long n4 = (long)this.y;
        long n5 = (long)this.width;
        long n6 = (long)this.height;
        long n7 = n5 + n3;
        long n8 = n6 + n4;
        long n9 = n3 - (long)n;
        long n10 = n4 - (long)n2;
        long n11 = n7 + (long)n;
        long n12 = n8 + (long)n2;
        long n13;
        if (n11 < n9) {
            n13 = n11 - n9;
            if (n13 < -2147483648L) {
                n13 = -2147483648L;
            }
            if (n9 < -2147483648L) {
                n9 = -2147483648L;
            }
            else if (n9 > 2147483647L) {
                n9 = 2147483647L;
            }
        }
        else {
            if (n9 < -2147483648L) {
                n9 = -2147483648L;
            }
            else if (n9 > 2147483647L) {
                n9 = 2147483647L;
            }
            n13 = n11 - n9;
            if (n13 < -2147483648L) {
                n13 = -2147483648L;
            }
            else if (n13 > 2147483647L) {
                n13 = 2147483647L;
            }
        }
        long n14;
        if (n12 < n10) {
            n14 = n12 - n10;
            if (n14 < -2147483648L) {
                n14 = -2147483648L;
            }
            if (n10 < -2147483648L) {
                n10 = -2147483648L;
            }
            else if (n10 > 2147483647L) {
                n10 = 2147483647L;
            }
        }
        else {
            if (n10 < -2147483648L) {
                n10 = -2147483648L;
            }
            else if (n10 > 2147483647L) {
                n10 = 2147483647L;
            }
            n14 = n12 - n10;
            if (n14 < -2147483648L) {
                n14 = -2147483648L;
            }
            else if (n14 > 2147483647L) {
                n14 = 2147483647L;
            }
        }
        this.reshape((int)n9, (int)n10, (int)n13, (int)n14);
    }
    
    @Override
    public boolean isEmpty() {
        return this.width <= 0 || this.height <= 0;
    }
    
    @Override
    public int outcode(double n, double n2) {
        int n3 = 0;
        if (this.width <= 0) {
            n3 |= 0x5;
        }
        else if (n < (double)this.x) {
            n3 |= 0x1;
        }
        else if (n > (double)this.x + (double)this.width) {
            n3 |= 0x4;
        }
        if (this.height <= 0) {
            n3 |= 0xA;
        }
        else if (n2 < (double)this.y) {
            n3 |= 0x2;
        }
        else if (n2 > (double)this.y + (double)this.height) {
            n3 |= 0x8;
        }
        return n3;
    }
    
    @Override
    public Rectangle2D createIntersection(Rectangle2D src2) {
        if ((src2 instanceof Rectangle)) {
            return this.intersection((Rectangle)src2);
        }
        Rectangle2D.Double dest = new Rectangle2D.Double();
        Rectangle2D.intersect(this, src2, dest);
        return dest;
    }
    
    @Override
    public Rectangle2D createUnion(Rectangle2D src2) {
        if ((src2 instanceof Rectangle)) {
            return this.union((Rectangle)src2);
        }
        Rectangle2D.Double dest = new Rectangle2D.Double();
        Rectangle2D.union(this, src2, dest);
        return dest;
    }
    
    @Override
    public boolean equals(Object obj) {
        if ((obj instanceof Rectangle)) {
            Rectangle rectangle = (Rectangle)obj;
            return this.x == rectangle.x && this.y == rectangle.y && this.width == rectangle.width && this.height == rectangle.height;
        }
        return super.equals(obj);
    }
    
    @Override
    public String toString() {
        return this.getClass().getName() + "[x=" + this.x + ",y=" + this.y + ",width=" + this.width + ",height=" + this.height + "]";
    }
    
    static {
        Toolkit.loadLibraries();
        if (!GraphicsEnvironment.isHeadless()) {
            initIDs();
        }
    }
}
